Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(154)

Unified Diff: chrome/renderer/render_view.h

Issue 2967007: Disable outdated plugins, block non-sandboxed plugins. (Closed)
Patch Set: '' Created 10 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/renderer/blocked_plugin.cc ('k') | chrome/renderer/render_view.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/renderer/render_view.h
diff --git a/chrome/renderer/render_view.h b/chrome/renderer/render_view.h
index f60669dba3e9de3c09dc816f2a06653b79c7da4f..994a78488b2afa8cc7a6854c922d205fa7ff3041 100644
--- a/chrome/renderer/render_view.h
+++ b/chrome/renderer/render_view.h
@@ -25,7 +25,6 @@
#include "chrome/common/content_settings.h"
#include "chrome/common/edit_command.h"
#include "chrome/common/navigation_gesture.h"
-#include "chrome/common/notification_type.h"
#include "chrome/common/page_zoom.h"
#include "chrome/common/render_messages.h"
#include "chrome/common/renderer_preferences.h"
@@ -82,6 +81,7 @@ class GURL;
class ListValue;
class NavigationState;
class PepperDeviceTest;
+class PluginGroup;
class PrintWebViewHelper;
class SkBitmap;
class WebPluginDelegatePepper;
@@ -277,10 +277,15 @@ class RenderView : public RenderWidget,
// the plugin.
void OnPepperPluginDestroy(WebPluginDelegatePepper* pepper_plugin);
- // Create a new plugin without checking the content settings.
- WebKit::WebPlugin* CreatePluginInternal(
- WebKit::WebFrame* frame,
- const WebKit::WebPluginParams& params);
+ // Create a new Pepper plugin without checking the content settings.
+ WebKit::WebPlugin* CreatePepperPlugin(pepper::PluginModule* pepper_module,
+ const WebKit::WebPluginParams& params);
+
+ // Create a new NPAPI plugin without checking the content settings.
+ WebKit::WebPlugin* CreateNPAPIPlugin(WebKit::WebFrame* frame,
+ const WebKit::WebPluginParams& params,
+ WebPluginInfo* plugin_info,
+ const std::string& mime_type);
// Asks the browser for the CPBrowsingContext associated with this renderer.
// This is an opaque identifier associated with the renderer for sending
@@ -778,6 +783,7 @@ class RenderView : public RenderWidget,
const std::string& origin,
const std::string& target);
void OnInstallMissingPlugin();
+ void OnLoadBlockedPlugins();
void OnMediaPlayerActionAt(const gfx::Point& location,
const WebKit::WebMediaPlayerAction& action);
void OnMoveOrResizeStarted();
@@ -864,7 +870,8 @@ class RenderView : public RenderWidget,
// Create a new placeholder for a blocked plugin.
WebKit::WebPlugin* CreatePluginPlaceholder(
WebKit::WebFrame* frame,
- const WebKit::WebPluginParams& params);
+ const WebKit::WebPluginParams& params,
+ PluginGroup* group);
// Sends an IPC notification that the specified content type was blocked.
void DidBlockContentType(ContentSettingsType settings_type);
« no previous file with comments | « chrome/renderer/blocked_plugin.cc ('k') | chrome/renderer/render_view.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698